@@ -55,8 +55,8 @@ import re
 import toml
 import time
 import math
+import lark
 from datetime import datetime
-from lark import UnexpectedCharacters, UnexpectedToken
 
 from kestrel.exceptions import (
     KestrelSyntaxError,
@@ -286,10 +286,18 @@ class Session(object):
                 self.config["language"]["default_variable"],
                 self.config["language"]["default_sort_order"],
             )
-        except UnexpectedCharacters as err:
-            raise KestrelSyntaxError(err.line, err.column, "character", err.char)
-        except UnexpectedToken as err:
-            raise KestrelSyntaxError(err.line, err.column, "token", err.token)
+        except lark.UnexpectedEOF as err:
+            raise KestrelSyntaxError(
+                err.line, err.column, "end of line", "", err.expected
+            )
+        except lark.UnexpectedCharacters as err:
+            raise KestrelSyntaxError(
+                err.line, err.column, "character", err.char, err.allowed
+            )
+        except lark.UnexpectedToken as err:
+            raise KestrelSyntaxError(
+                err.line, err.column, "token", err.token, err.accepts or err.expected
+            )
         return ast
 
     def get_variable_names(self):
